Conversion

Struct Conversion 

pub struct Conversion {
    pub from_unit: &'static str,
    pub to_unit: &'static str,
    pub factor: f64,
    pub offset: f64,
}
A linear or affine conversion between two unit labels.

Fields

from_unit: &'static strto_unit: &'static strfactor: f64offset: f64

Implementations

Source

impl Conversion

pub const fn linear( from_unit: &'static str, to_unit: &'static str, factor: f64, ) -> Self

Creates a linear conversion with no offset.

pub const fn affine( from_unit: &'static str, to_unit: &'static str, factor: f64, offset: f64, ) -> Self

Creates an affine conversion with both a factor and offset.

pub fn apply(self, value: f64) -> f64

Applies the conversion to a raw scalar value.